@@ -72,6 +72,8 @@ class AutoControl():
                 if (i+1) % yield_batches == 0:
                     loss /= yield_batches
                     epoch_finished = False
+                    if (i+1) == len(self.trainloader):
+                        epoch_finished = True
                 elif i == len(self.trainloader)-1:
                     loss /= len(self.trainloader) % yield_batches
                     epoch_finished = True
