@@ -1,10 +1,10 @@
-from .utils import Dataset
+from . import utils
 from .ldl import FlickrLDL, TwitterLDL
 from .iaps import IAPS, NAPS
 from .emotion_roi import EmotionROI
 from .emod import EMOd
 from .fi import FI
+import sys
+sys.path.append('.')
 
-__all__ = [
-    'Dataset', 'FlickrLDL', 'TwitterLDL', 'IAPS', 'NAPS', 'EmotionROI', 'EMOd', 'FI',
-]
+__all__ = ['utils', 'FlickrLDL', 'TwitterLDL', 'IAPS', 'NAPS', 'EmotionROI', 'EMOd', 'FI']
