@@ -3,6 +3,7 @@ from .basic import empty_transform
 from .basic import resize_centercrop_flip
 from .basic import resize_rdcrop_flip
 from . import casnet_cvpr_2018
+from .utils import ChainedTransform
 
 __all__ = ['utils', 'empty_transform', 'resize_centercrop_flip', 'resize_rdcrop_flip',
-           'casnet_cvpr_2018']
+           'casnet_cvpr_2018', 'ChainedTransform']
